%define upstream_name    Spreadsheet-ReadSXC
%define upstream_version 0.39

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 2

Summary:    Extract OpenOffice 1.x spreadsheet data
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Spreadsheet/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Archive::Zip) >= 1.340.0
BuildRequires: perl(Carp)
BuildRequires: perl(Data::Dumper)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Basename)
BuildRequires: perl(File::Temp)
BuildRequires: perl(Filter::signatures) >= 0.160.0
BuildRequires: perl(Moo) >= 2.0.0
BuildRequires: perl(PerlIO::gzip)
BuildRequires: perl(PerlX::Maybe)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Storable)
BuildRequires: perl(Test::More)
BuildRequires: perl(XML::Twig) >= 3.500.0
BuildRequires: perl(XML::Twig::XPath)
BuildRequires: perl(XML::XPath)
BuildRequires: perl(XML::XPathEngine)
BuildArch:  noarch

%description
Spreadsheet::ReadSXC extracts data from OpenOffice 1.x spreadsheet files
(.sxc). It exports the function read_sxc() which takes a filename and an
optional reference to a hash of options as arguments and returns a
reference to a hash of references to two-dimensional arrays. The hash keys
correspond to the names of worksheets in the OpenOffice workbook. The
two-dimensional arrays correspond to rows and cells in the respective
spreadsheets. If you don't like this because the order of sheets is not
preserved in a hash, read on. The 'OrderBySheet' option provides an array
of hashes instead.

If you prefer to unpack the .sxc file yourself, you can use the function
read_xml_file() instead and pass the path to content.xml as an argument. Or
you can extract the XML string from content.xml and pass the string to the
function read_xml_string(). Both functions also take a reference to a hash
of options as an optional second argument.

Spreadsheet::ReadSXC requires XML::Parser to parse the XML contained in
.sxc files. Only the contents of text:p elements are returned, not the
actual values of table:value attributes. For example, a cell might have a
table:value-type attribute of "currency", a table:value attribute of
"-1500.99" and a table:currency attribute of "USD". The text:p element
would contain "-$1,500.99". This is the string which is returned by the
read_sxc() function, not the value of -1500.99.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%perl_vendorlib/*

%changelog
* Sun Jun 29 2025 umeabot <umeabot> 0.390.0-2.mga10
+ Revision: 2227088
- Mageia 10 Mass Rebuild

* Sat Aug 24 2024 tv <tv> 0.390.0-1.mga10
+ Revision: 2090891
- update to 0.39

* Wed Aug 30 2023 tv <tv> 0.380.0-1.mga10
+ Revision: 1981952
- update to 0.38

* Wed Mar 23 2022 umeabot <umeabot> 0.370.0-2.mga9
+ Revision: 1820883
- Mageia 9 Mass Rebuild

* Mon Nov 22 2021 tv <tv> 0.370.0-1.mga9
+ Revision: 1758618
- update to 0.37

* Fri Sep 10 2021 tv <tv> 0.350.0-1.mga9
+ Revision: 1745028
- update to 0.35

* Thu Mar 11 2021 tv <tv> 0.340.0-1.mga9
+ Revision: 1701377
- update to 0.34

* Tue Dec 29 2020 tv <tv> 0.330.0-1.mga8
+ Revision: 1664673
- update to 0.33

* Wed Oct 07 2020 tv <tv> 0.320.0-1.mga8
+ Revision: 1632486
- update to 0.32

* Mon Oct 05 2020 tv <tv> 0.310.0-1.mga8
+ Revision: 1632234
- update to 0.31

* Sun Oct 04 2020 tv <tv> 0.300.0-1.mga8
+ Revision: 1632145
- update to 0.30

* Thu Oct 01 2020 tv <tv> 0.290.0-1.mga8
+ Revision: 1631380
- update to 0.29

* Wed Sep 30 2020 tv <tv> 0.280.0-1.mga8
+ Revision: 1631281
- update to 0.28

* Tue Sep 29 2020 tv <tv> 0.270.0-1.mga8
+ Revision: 1631055
- update to 0.27

* Sun Feb 16 2020 umeabot <umeabot> 0.240.0-2.mga8
+ Revision: 1535055
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%makeinstall_std

* Wed Oct 09 2019 tv <tv> 0.240.0-1.mga8
+ Revision: 1450752
- update to 0.24

* Fri Oct 04 2019 tv <tv> 0.230.0-1.mga8
+ Revision: 1449299
- update to 0.23

* Thu Oct 03 2019 tv <tv> 0.210.0-1.mga8
+ Revision: 1449053
- update to 0.21

* Wed Sep 19 2018 umeabot <umeabot> 0.200.0-8.mga7
+ Revision: 1271212
- Mageia 7 Mass Rebuild

* Sun Jun 19 2016 pterjan <pterjan> 0.200.0-7.mga6
+ Revision: 1033323
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.200.0-6.mga6
+ Revision: 945560
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 0.200.0-5.mga5
+ Revision: 747895
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.200.0-4.mga5
+ Revision: 686222
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 0.200.0-3.mga4
+ Revision: 514657
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.200.0-2.mga3
+ Revision: 372714
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Jan 21 2011 jquelin <jquelin> 0.200.0-1.mga1
+ Revision: 28769
- mageia rebuild
- imported package perl-Spreadsheet-ReadSXC

